@@ -1,7 +1,7 @@
 /*
  * fsarchiver: Filesystem Archiver
  *
- * Copyright (C) 2008-2009 Francois Dupoux.  All rights reserved.
+ * Copyright (C) 2008-2010 Francois Dupoux.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -15,19 +15,17 @@
  * Homepage: http://www.fsarchiver.org
  */
 
-#include "fsarchiver.h"
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
 
-#include <stdio.h>
 #include <string.h>
-#include <strings.h>
-#include <sys/types.h>
 #include <sys/stat.h>
-#include <unistd.h>
 #include <sys/vfs.h>
 #include <sys/utsname.h>
-#include <linux/limits.h>
 #include <sys/mount.h>
 
+#include "fsarchiver.h"
 #include "common.h"
 #include "filesys.h"
 #include "fs_ext2.h"
@@ -37,6 +35,7 @@
 #include "fs_xfs.h"
 #include "fs_jfs.h"
 #include "fs_ntfs.h"
+#include "error.h"
 
 cfilesys filesys[]=
 {
@@ -224,52 +223,3 @@ char *format_prog_version(u64 version, char *bufdat, int buflen)
     snprintf(bufdat, buflen, "%ld.%ld.%ld", (long)(version>>16&0xFF), (long)(version>>8&0xFF), (long)(version>>0&0xFF));
     return bufdat;
 }
-
-u64 check_prog_version(char *prog)
-{
-    char stderrbuf[2048];
-    char command[2048];
-    char options[1024];
-    char temp1[1024];
-    char delims[]="\n\r";
-    char *saveptr;
-    char *result;
-    int foundversion;
-    int x, y, z;
-    
-    // init
-    memset(options, 0, sizeof(options));
-    
-    // check that mount.ntfs-3g is available and that it supports "streams_interface"
-    if (exec_command(command, sizeof(command), NULL, 0, NULL, 0, "which %s", prog)!=0)
-    {   errprintf("%s not found.\n", prog);
-        return -1;
-    }
-    
-    memset(stderrbuf, 0, sizeof(stderrbuf));
-    exec_command(command, sizeof(command), NULL, 0, stderrbuf, sizeof(stderrbuf), "%s -V", prog);
-    
-    foundversion=false;
-    result=strtok_r(stderrbuf, delims, &saveptr);
-    while (result != NULL && foundversion==false)
-    {   if ((memcmp(result, prog, strlen(prog))==0))
-            foundversion=true;
-        else
-            result = strtok_r(NULL, delims, &saveptr);
-    }
-    
-    if (foundversion==false)
-    {   errprintf("can't parse %s version number: no match\n", prog);
-        return 0;
-    }
-    
-    x=y=z=0;
-    sscanf(result, "%s %d.%d.%d", temp1, &x, &y, &z);
-    
-    if (x==0 && y==0)
-    {   errprintf("can't parse %s version number: x=y=0\n", prog);
-        return 0;
-    }
-    
-    return PROGVER(x,y,z);
-}
