@@ -1,7 +1,7 @@
 /*
  * fsarchiver: Filesystem Archiver
  *
- * Copyright (C) 2008-2009 Francois Dupoux.  All rights reserved.
+ * Copyright (C) 2008-2010 Francois Dupoux.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -18,8 +18,8 @@
 #ifndef __FS_NTFS_H__
 #define __FS_NTFS_H__
 
-#include "dico.h"
-#include "strlist.h"
+struct s_dico;
+struct s_strlist;
 
 #define NTFS3G_VERSION(year, month, day)    ((u64)((((u64)year&0xFFFF)<<48)+(((u64)month&0xFFFF)<<32)+(((u64)day&0xFFFF)<<16)))
 #define NTFS3G_MINVER_Y                     2009
@@ -29,18 +29,14 @@
 struct s_ntfsinfo
 {   u32 bytes_per_sector;
     u32 sectors_per_clusters;
-    u64 total_sector_count;
-    u64 lcn_of_mft_data_attrib;
     u32 bytes_per_cluster;
-    u32 file_record_size;
-    s32 clusters_per_mft_record;
     u64 uuid;
 };
 
-int ntfs_mkfs(cdico *d, char *partition);
-int ntfs_getinfo(cdico *d, char *devname);
+int ntfs_mkfs(struct s_dico *d, char *partition);
+int ntfs_getinfo(struct s_dico *d, char *devname);
 int ntfs_mount(char *partition, char *mntbuf, char *fsbuf, int flags, char *mntinfo);
-int ntfs_get_reqmntopt(char *partition, cstrlist *reqopt, cstrlist *badopt);
+int ntfs_get_reqmntopt(char *partition, struct s_strlist *reqopt, struct s_strlist *badopt);
 int ntfs_replace_uuid(char *devname, u64 uuid);
 int ntfs_umount(char *partition, char *mntbuf);
 int ntfs_test(char *devname);
